!!ARBvp1.0

# cel shader (vertex shader) for single texturing


# input
ATTRIB OriginalPos	= vertex.position;	# input vertex position
ATTRIB OriginalColor	= vertex.color;		# input vertex color
ATTRIB OriginalNormal	= vertex.normal;	# input vertex normal


# output
OUTPUT OutPos		= result.position;	# output position
OUTPUT OutColor		= result.color;		# output color
OUTPUT OutTex0		= result.texcoord[0];	# output texture coordinate 0


# parameters
PARAM ModelViewProj[4]  = { state.matrix.mvp }; # modelview projection matrix
PARAM LightPosition	= program.env[0];	# light position sent in from the application

# temporary variables
TEMP lightVector;				# holds the light vector
TEMP lightVectorNormal;				# holds the normalized light vector



# transform each axis into clip space
DP4 OutPos.x, ModelViewProj[0], OriginalPos;
DP4 OutPos.y, ModelViewProj[1], OriginalPos;
DP4 OutPos.z, ModelViewProj[2], OriginalPos;
DP4 OutPos.w, ModelViewProj[3], OriginalPos;


# output color = original color
MOV OutColor, OriginalColor;


# calculate the light vector
SUB lightVector, LightPosition, OriginalPos;


# normalize the light vector
DP3 lightVectorNormal.w, lightVector, lightVector;
RSQ lightVectorNormal.w, lightVectorNormal.w;
MUL lightVectorNormal.xyz, lightVectorNormal.w, lightVector;


# dp3 the light vector with vertex normal and send
# it to the output of texture coordinate 0
# output between 0 and 1 mapps the luminance texture map
DP3 OutTex0.x, lightVectorNormal, OriginalNormal;

END